/* File: ctrl_undo_redo_list_test.h; Copyright and License: see below */

#ifndef CTRL_UNDO_REDO_LIST_TEST_H
#define CTRL_UNDO_REDO_LIST_TEST_H

/*!
 *  \file
 *  \brief MODULE TEST for data_database_writer, data_database_sql_builder,
 *                         data_database, data_database_reader, ctrl_undo_redo_list
 */

#include "test_suite.h"

test_suite_t ctrl_undo_redo_list_test_get_suite(void);

#endif  /* CTRL_UNDO_REDO_LIST_TEST_H */


/*
 * Copyright 2016-2021 Andreas Warnke
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
